@@ -7,7 +7,7 @@ from sphinx.application import Sphinx
 from sphinx.util.fileutil import copy_asset_file
 from sphinx_book_theme import hash_assets_for_files
 
-from . import nodes
+from . import extensions
 
 
 def get_html_theme_path():
@@ -39,4 +39,4 @@ def setup(app: Sphinx):
     app.connect('html-page-context', hash_js_css_assets)
     app.connect('build-finished', copy_custom_files)
 
-    nodes.setup(app)
+    extensions.setup(app)
